# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/containerregistry/v1/ip_permission.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/containerregistry/v1/ip_permission.proto',
  package='yandex.cloud.containerregistry.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5yandex/cloud/containerregistry/v1/ip_permission.proto\x12!yandex.cloud.containerregistry.v1\x1a\x1dyandex/cloud/validation.proto\"\x98\x01\n\x0cIpPermission\x12\x46\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x36.yandex.cloud.containerregistry.v1.IpPermission.Action\x12\n\n\x02ip\x18\x02 \x01(\t\"4\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\x08\n\x04PULL\x10\x01\x12\x08\n\x04PUSH\x10\x02\"\xae\x01\n\x11IpPermissionDelta\x12K\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x35.yandex.cloud.containerregistry.v1.IpPermissionActionB\x04\xe8\xc7\x31\x01\x12L\n\rip_permission\x18\x02 \x01(\x0b\x32/.yandex.cloud.containerregistry.v1.IpPermissionB\x04\xe8\xc7\x31\x01*O\n\x12IpPermissionAction\x12$\n IP_PERMISSION_ACTION_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41\x44\x44\x10\x01\x12\n\n\x06REMOVE\x10\x02\x42\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])

_IPPERMISSIONACTION = _descriptor.EnumDescriptor(
  name='IpPermissionAction',
  full_name='yandex.cloud.containerregistry.v1.IpPermissionAction',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IP_PERMISSION_ACTION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ADD', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REMOVE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=455,
  serialized_end=534,
)
_sym_db.RegisterEnumDescriptor(_IPPERMISSIONACTION)

IpPermissionAction = enum_type_wrapper.EnumTypeWrapper(_IPPERMISSIONACTION)
IP_PERMISSION_ACTION_UNSPECIFIED = 0
ADD = 1
REMOVE = 2


_IPPERMISSION_ACTION = _descriptor.EnumDescriptor(
  name='Action',
  full_name='yandex.cloud.containerregistry.v1.IpPermission.Action',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PULL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PUSH', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=224,
  serialized_end=276,
)
_sym_db.RegisterEnumDescriptor(_IPPERMISSION_ACTION)


_IPPERMISSION = _descriptor.Descriptor(
  name='IpPermission',
  full_name='yandex.cloud.containerregistry.v1.IpPermission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='yandex.cloud.containerregistry.v1.IpPermission.action', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip', full_name='yandex.cloud.containerregistry.v1.IpPermission.ip', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _IPPERMISSION_ACTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=276,
)


_IPPERMISSIONDELTA = _descriptor.Descriptor(
  name='IpPermissionDelta',
  full_name='yandex.cloud.containerregistry.v1.IpPermissionDelta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='yandex.cloud.containerregistry.v1.IpPermissionDelta.action', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_permission', full_name='yandex.cloud.containerregistry.v1.IpPermissionDelta.ip_permission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=453,
)

_IPPERMISSION.fields_by_name['action'].enum_type = _IPPERMISSION_ACTION
_IPPERMISSION_ACTION.containing_type = _IPPERMISSION
_IPPERMISSIONDELTA.fields_by_name['action'].enum_type = _IPPERMISSIONACTION
_IPPERMISSIONDELTA.fields_by_name['ip_permission'].message_type = _IPPERMISSION
DESCRIPTOR.message_types_by_name['IpPermission'] = _IPPERMISSION
DESCRIPTOR.message_types_by_name['IpPermissionDelta'] = _IPPERMISSIONDELTA
DESCRIPTOR.enum_types_by_name['IpPermissionAction'] = _IPPERMISSIONACTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IpPermission = _reflection.GeneratedProtocolMessageType('IpPermission', (_message.Message,), {
  'DESCRIPTOR' : _IPPERMISSION,
  '__module__' : 'yandex.cloud.containerregistry.v1.ip_permission_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.IpPermission)
  })
_sym_db.RegisterMessage(IpPermission)

IpPermissionDelta = _reflection.GeneratedProtocolMessageType('IpPermissionDelta', (_message.Message,), {
  'DESCRIPTOR' : _IPPERMISSIONDELTA,
  '__module__' : 'yandex.cloud.containerregistry.v1.ip_permission_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.IpPermissionDelta)
  })
_sym_db.RegisterMessage(IpPermissionDelta)


DESCRIPTOR._options = None
_IPPERMISSIONDELTA.fields_by_name['action']._options = None
_IPPERMISSIONDELTA.fields_by_name['ip_permission']._options = None
# @@protoc_insertion_point(module_scope)
