# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ydb/v1/storage_type_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.ydb.v1 import storage_type_pb2 as yandex_dot_cloud_dot_ydb_dot_v1_dot_storage__type__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/ydb/v1/storage_type_service.proto',
  package='yandex.cloud.ydb.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.yandex/cloud/ydb/v1/storage_type_service.proto\x12\x13yandex.cloud.ydb.v1\x1a\x1cgoogle/api/annotations.proto\x1a&yandex/cloud/ydb/v1/storage_type.proto\x1a\x1dyandex/cloud/validation.proto\"6\n\x15GetStorageTypeRequest\x12\x1d\n\x0fstorage_type_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"W\n\x17ListStorageTypesRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\"l\n\x18ListStorageTypesResponse\x12\x37\n\rstorage_types\x18\x01 \x03(\x0b\x32 .yandex.cloud.ydb.v1.StorageType\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x9e\x02\n\x12StorageTypeService\x12\x83\x01\n\x03Get\x12*.yandex.cloud.ydb.v1.GetStorageTypeRequest\x1a .yandex.cloud.ydb.v1.StorageType\".\x82\xd3\xe4\x93\x02(\x12&/ydb/v1/storageTypes/{storage_type_id}\x12\x81\x01\n\x04List\x12,.yandex.cloud.ydb.v1.ListStorageTypesRequest\x1a-.yandex.cloud.ydb.v1.ListStorageTypesResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/ydb/v1/storageTypesBV\n\x17yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydbb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_ydb_dot_v1_dot_storage__type__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETSTORAGETYPEREQUEST = _descriptor.Descriptor(
  name='GetStorageTypeRequest',
  full_name='yandex.cloud.ydb.v1.GetStorageTypeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_type_id', full_name='yandex.cloud.ydb.v1.GetStorageTypeRequest.storage_type_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=172,
  serialized_end=226,
)


_LISTSTORAGETYPESREQUEST = _descriptor.Descriptor(
  name='ListStorageTypesRequest',
  full_name='yandex.cloud.ydb.v1.ListStorageTypesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.ydb.v1.ListStorageTypesRequest.page_size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.ydb.v1.ListStorageTypesRequest.page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=228,
  serialized_end=315,
)


_LISTSTORAGETYPESRESPONSE = _descriptor.Descriptor(
  name='ListStorageTypesResponse',
  full_name='yandex.cloud.ydb.v1.ListStorageTypesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_types', full_name='yandex.cloud.ydb.v1.ListStorageTypesResponse.storage_types', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.ydb.v1.ListStorageTypesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=317,
  serialized_end=425,
)

_LISTSTORAGETYPESRESPONSE.fields_by_name['storage_types'].message_type = yandex_dot_cloud_dot_ydb_dot_v1_dot_storage__type__pb2._STORAGETYPE
DESCRIPTOR.message_types_by_name['GetStorageTypeRequest'] = _GETSTORAGETYPEREQUEST
DESCRIPTOR.message_types_by_name['ListStorageTypesRequest'] = _LISTSTORAGETYPESREQUEST
DESCRIPTOR.message_types_by_name['ListStorageTypesResponse'] = _LISTSTORAGETYPESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetStorageTypeRequest = _reflection.GeneratedProtocolMessageType('GetStorageTypeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTORAGETYPEREQUEST,
  '__module__' : 'yandex.cloud.ydb.v1.storage_type_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.GetStorageTypeRequest)
  })
_sym_db.RegisterMessage(GetStorageTypeRequest)

ListStorageTypesRequest = _reflection.GeneratedProtocolMessageType('ListStorageTypesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTORAGETYPESREQUEST,
  '__module__' : 'yandex.cloud.ydb.v1.storage_type_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.ListStorageTypesRequest)
  })
_sym_db.RegisterMessage(ListStorageTypesRequest)

ListStorageTypesResponse = _reflection.GeneratedProtocolMessageType('ListStorageTypesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTORAGETYPESRESPONSE,
  '__module__' : 'yandex.cloud.ydb.v1.storage_type_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.ydb.v1.ListStorageTypesResponse)
  })
_sym_db.RegisterMessage(ListStorageTypesResponse)


DESCRIPTOR._options = None
_GETSTORAGETYPEREQUEST.fields_by_name['storage_type_id']._options = None
_LISTSTORAGETYPESREQUEST.fields_by_name['page_size']._options = None
_LISTSTORAGETYPESREQUEST.fields_by_name['page_token']._options = None

_STORAGETYPESERVICE = _descriptor.ServiceDescriptor(
  name='StorageTypeService',
  full_name='yandex.cloud.ydb.v1.StorageTypeService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=428,
  serialized_end=714,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.ydb.v1.StorageTypeService.Get',
    index=0,
    containing_service=None,
    input_type=_GETSTORAGETYPEREQUEST,
    output_type=yandex_dot_cloud_dot_ydb_dot_v1_dot_storage__type__pb2._STORAGETYPE,
    serialized_options=b'\202\323\344\223\002(\022&/ydb/v1/storageTypes/{storage_type_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.ydb.v1.StorageTypeService.List',
    index=1,
    containing_service=None,
    input_type=_LISTSTORAGETYPESREQUEST,
    output_type=_LISTSTORAGETYPESRESPONSE,
    serialized_options=b'\202\323\344\223\002\026\022\024/ydb/v1/storageTypes',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STORAGETYPESERVICE)

DESCRIPTOR.services_by_name['StorageTypeService'] = _STORAGETYPESERVICE

# @@protoc_insertion_point(module_scope)
