# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/mdbproxy/v1/proxy_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.serverless.mdbproxy.v1 import proxy_pb2 as yandex_dot_cloud_dot_serverless_dot_mdbproxy_dot_v1_dot_proxy__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/serverless/mdbproxy/v1/proxy_service.proto',
  package='yandex.cloud.serverless.mdbproxy.v1',
  syntax='proto3',
  serialized_options=b'\n\'yandex.cloud.api.serverless.mdbproxy.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/mdbproxy/v1;proxy',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7yandex/cloud/serverless/mdbproxy/v1/proxy_service.proto\x12#yandex.cloud.serverless.mdbproxy.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a/yandex/cloud/serverless/mdbproxy/v1/proxy.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"1\n\x0fGetProxyRequest\x12\x1e\n\x08proxy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x8d\x01\n\x10ListProxyRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"t\n\x11ListProxyResponse\x12;\n\x07proxies\x18\x01 \x03(\x0b\x32*.yandex.cloud.serverless.mdbproxy.v1.Proxy\x12\"\n\x0fnext_page_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x8f\x03\n\x12\x43reateProxyRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9c\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x43.yandex.cloud.serverless.mdbproxy.v1.CreateProxyRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\x41\n\x06target\x18\x05 \x01(\x0b\x32+.yandex.cloud.serverless.mdbproxy.v1.TargetB\x04\xe8\xc7\x31\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"1\n\x13\x43reateProxyMetadata\x12\x1a\n\x08proxy_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"\xb9\x03\n\x12UpdateProxyRequest\x12\x16\n\x08proxy_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9c\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x43.yandex.cloud.serverless.mdbproxy.v1.UpdateProxyRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12;\n\x06target\x18\x06 \x01(\x0b\x32+.yandex.cloud.serverless.mdbproxy.v1.Target\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"5\n\x13UpdateProxyMetadata\x12\x1e\n\x08proxy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"4\n\x12\x44\x65leteProxyRequest\x12\x1e\n\x08proxy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"5\n\x13\x44\x65leteProxyMetadata\x12\x1e\n\x08proxy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x8e\x01\n\x1aListProxyOperationsRequest\x12\x16\n\x08proxy_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"m\n\x1bListProxyOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xac\r\n\x0cProxyService\x12\x90\x01\n\x03Get\x12\x34.yandex.cloud.serverless.mdbproxy.v1.GetProxyRequest\x1a*.yandex.cloud.serverless.mdbproxy.v1.Proxy\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/mdbproxy/v1/proxies/{proxy_id}\x12\x93\x01\n\x04List\x12\x35.yandex.cloud.serverless.mdbproxy.v1.ListProxyRequest\x1a\x36.yandex.cloud.serverless.mdbproxy.v1.ListProxyResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/mdbproxy/v1/proxies\x12\xa5\x01\n\x06\x43reate\x12\x37.yandex.cloud.serverless.mdbproxy.v1.CreateProxyRequest\x1a!.yandex.cloud.operation.Operation\"?\x82\xd3\xe4\x93\x02\x19\"\x14/mdbproxy/v1/proxies:\x01*\xb2\xd2*\x1c\n\x13\x43reateProxyMetadata\x12\x05Proxy\x12\xb0\x01\n\x06Update\x12\x37.yandex.cloud.serverless.mdbproxy.v1.UpdateProxyRequest\x1a!.yandex.cloud.operation.Operation\"J\x82\xd3\xe4\x93\x02$2\x1f/mdbproxy/v1/proxies/{proxy_id}:\x01*\xb2\xd2*\x1c\n\x13UpdateProxyMetadata\x12\x05Proxy\x12\xbd\x01\n\x06\x44\x65lete\x12\x37.yandex.cloud.serverless.mdbproxy.v1.DeleteProxyRequest\x1a!.yandex.cloud.operation.Operation\"W\x82\xd3\xe4\x93\x02!*\x1f/mdbproxy/v1/proxies/{proxy_id}\xb2\xd2*,\n\x13\x44\x65leteProxyMetadata\x12\x15google.protobuf.Empty\x12\xc7\x01\n\x0eListOperations\x12?.yandex.cloud.serverless.mdbproxy.v1.ListProxyOperationsRequest\x1a@.yandex.cloud.serverless.mdbproxy.v1.ListProxyOperationsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/mdbproxy/v1/proxies/{proxy_id}/operations\x12\xb4\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/mdbproxy/v1/proxies/{resource_id}:listAccessBindings\x12\xe3\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"|\x82\xd3\xe4\x93\x02\x39\"4/mdbproxy/v1/proxies/{resource_id}:setAccessBindings:\x01*\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\xf0\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x82\x01\x82\xd3\xe4\x93\x02<27/mdbproxy/v1/proxies/{resource_id}:updateAccessBindings:\x01*\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.EmptyBx\n\'yandex.cloud.api.serverless.mdbproxy.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/mdbproxy/v1;proxyb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_access_dot_access__pb2.DESCRIPTOR,yandex_dot_cloud_dot_serverless_dot_mdbproxy_dot_v1_dot_proxy__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETPROXYREQUEST = _descriptor.Descriptor(
  name='GetProxyRequest',
  full_name='yandex.cloud.serverless.mdbproxy.v1.GetProxyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proxy_id', full_name='yandex.cloud.serverless.mdbproxy.v1.GetProxyRequest.proxy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=348,
  serialized_end=397,
)


_LISTPROXYREQUEST = _descriptor.Descriptor(
  name='ListProxyRequest',
  full_name='yandex.cloud.serverless.mdbproxy.v1.ListProxyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.serverless.mdbproxy.v1.ListProxyRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.serverless.mdbproxy.v1.ListProxyRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.serverless.mdbproxy.v1.ListProxyRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.serverless.mdbproxy.v1.ListProxyRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=400,
  serialized_end=541,
)


_LISTPROXYRESPONSE = _descriptor.Descriptor(
  name='ListProxyResponse',
  full_name='yandex.cloud.serverless.mdbproxy.v1.ListProxyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proxies', full_name='yandex.cloud.serverless.mdbproxy.v1.ListProxyResponse.proxies', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.serverless.mdbproxy.v1.ListProxyResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=543,
  serialized_end=659,
)


_CREATEPROXYREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.serverless.mdbproxy.v1.CreateProxyRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.serverless.mdbproxy.v1.CreateProxyRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.serverless.mdbproxy.v1.CreateProxyRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1016,
  serialized_end=1061,
)

_CREATEPROXYREQUEST = _descriptor.Descriptor(
  name='CreateProxyRequest',
  full_name='yandex.cloud.serverless.mdbproxy.v1.CreateProxyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.serverless.mdbproxy.v1.CreateProxyRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.serverless.mdbproxy.v1.CreateProxyRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.serverless.mdbproxy.v1.CreateProxyRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.serverless.mdbproxy.v1.CreateProxyRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='yandex.cloud.serverless.mdbproxy.v1.CreateProxyRequest.target', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEPROXYREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=662,
  serialized_end=1061,
)


_CREATEPROXYMETADATA = _descriptor.Descriptor(
  name='CreateProxyMetadata',
  full_name='yandex.cloud.serverless.mdbproxy.v1.CreateProxyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proxy_id', full_name='yandex.cloud.serverless.mdbproxy.v1.CreateProxyMetadata.proxy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1063,
  serialized_end=1112,
)


_UPDATEPROXYREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.serverless.mdbproxy.v1.UpdateProxyRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.serverless.mdbproxy.v1.UpdateProxyRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.serverless.mdbproxy.v1.UpdateProxyRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1016,
  serialized_end=1061,
)

_UPDATEPROXYREQUEST = _descriptor.Descriptor(
  name='UpdateProxyRequest',
  full_name='yandex.cloud.serverless.mdbproxy.v1.UpdateProxyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proxy_id', full_name='yandex.cloud.serverless.mdbproxy.v1.UpdateProxyRequest.proxy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.serverless.mdbproxy.v1.UpdateProxyRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.serverless.mdbproxy.v1.UpdateProxyRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.serverless.mdbproxy.v1.UpdateProxyRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.serverless.mdbproxy.v1.UpdateProxyRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='yandex.cloud.serverless.mdbproxy.v1.UpdateProxyRequest.target', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEPROXYREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1115,
  serialized_end=1556,
)


_UPDATEPROXYMETADATA = _descriptor.Descriptor(
  name='UpdateProxyMetadata',
  full_name='yandex.cloud.serverless.mdbproxy.v1.UpdateProxyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proxy_id', full_name='yandex.cloud.serverless.mdbproxy.v1.UpdateProxyMetadata.proxy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1558,
  serialized_end=1611,
)


_DELETEPROXYREQUEST = _descriptor.Descriptor(
  name='DeleteProxyRequest',
  full_name='yandex.cloud.serverless.mdbproxy.v1.DeleteProxyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proxy_id', full_name='yandex.cloud.serverless.mdbproxy.v1.DeleteProxyRequest.proxy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1613,
  serialized_end=1665,
)


_DELETEPROXYMETADATA = _descriptor.Descriptor(
  name='DeleteProxyMetadata',
  full_name='yandex.cloud.serverless.mdbproxy.v1.DeleteProxyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proxy_id', full_name='yandex.cloud.serverless.mdbproxy.v1.DeleteProxyMetadata.proxy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1667,
  serialized_end=1720,
)


_LISTPROXYOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListProxyOperationsRequest',
  full_name='yandex.cloud.serverless.mdbproxy.v1.ListProxyOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proxy_id', full_name='yandex.cloud.serverless.mdbproxy.v1.ListProxyOperationsRequest.proxy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.serverless.mdbproxy.v1.ListProxyOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.serverless.mdbproxy.v1.ListProxyOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.serverless.mdbproxy.v1.ListProxyOperationsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1723,
  serialized_end=1865,
)


_LISTPROXYOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListProxyOperationsResponse',
  full_name='yandex.cloud.serverless.mdbproxy.v1.ListProxyOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.serverless.mdbproxy.v1.ListProxyOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.serverless.mdbproxy.v1.ListProxyOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1867,
  serialized_end=1976,
)

_LISTPROXYRESPONSE.fields_by_name['proxies'].message_type = yandex_dot_cloud_dot_serverless_dot_mdbproxy_dot_v1_dot_proxy__pb2._PROXY
_CREATEPROXYREQUEST_LABELSENTRY.containing_type = _CREATEPROXYREQUEST
_CREATEPROXYREQUEST.fields_by_name['labels'].message_type = _CREATEPROXYREQUEST_LABELSENTRY
_CREATEPROXYREQUEST.fields_by_name['target'].message_type = yandex_dot_cloud_dot_serverless_dot_mdbproxy_dot_v1_dot_proxy__pb2._TARGET
_UPDATEPROXYREQUEST_LABELSENTRY.containing_type = _UPDATEPROXYREQUEST
_UPDATEPROXYREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEPROXYREQUEST.fields_by_name['labels'].message_type = _UPDATEPROXYREQUEST_LABELSENTRY
_UPDATEPROXYREQUEST.fields_by_name['target'].message_type = yandex_dot_cloud_dot_serverless_dot_mdbproxy_dot_v1_dot_proxy__pb2._TARGET
_LISTPROXYOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetProxyRequest'] = _GETPROXYREQUEST
DESCRIPTOR.message_types_by_name['ListProxyRequest'] = _LISTPROXYREQUEST
DESCRIPTOR.message_types_by_name['ListProxyResponse'] = _LISTPROXYRESPONSE
DESCRIPTOR.message_types_by_name['CreateProxyRequest'] = _CREATEPROXYREQUEST
DESCRIPTOR.message_types_by_name['CreateProxyMetadata'] = _CREATEPROXYMETADATA
DESCRIPTOR.message_types_by_name['UpdateProxyRequest'] = _UPDATEPROXYREQUEST
DESCRIPTOR.message_types_by_name['UpdateProxyMetadata'] = _UPDATEPROXYMETADATA
DESCRIPTOR.message_types_by_name['DeleteProxyRequest'] = _DELETEPROXYREQUEST
DESCRIPTOR.message_types_by_name['DeleteProxyMetadata'] = _DELETEPROXYMETADATA
DESCRIPTOR.message_types_by_name['ListProxyOperationsRequest'] = _LISTPROXYOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListProxyOperationsResponse'] = _LISTPROXYOPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetProxyRequest = _reflection.GeneratedProtocolMessageType('GetProxyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROXYREQUEST,
  '__module__' : 'yandex.cloud.serverless.mdbproxy.v1.proxy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.mdbproxy.v1.GetProxyRequest)
  })
_sym_db.RegisterMessage(GetProxyRequest)

ListProxyRequest = _reflection.GeneratedProtocolMessageType('ListProxyRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROXYREQUEST,
  '__module__' : 'yandex.cloud.serverless.mdbproxy.v1.proxy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.mdbproxy.v1.ListProxyRequest)
  })
_sym_db.RegisterMessage(ListProxyRequest)

ListProxyResponse = _reflection.GeneratedProtocolMessageType('ListProxyResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROXYRESPONSE,
  '__module__' : 'yandex.cloud.serverless.mdbproxy.v1.proxy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.mdbproxy.v1.ListProxyResponse)
  })
_sym_db.RegisterMessage(ListProxyResponse)

CreateProxyRequest = _reflection.GeneratedProtocolMessageType('CreateProxyRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEPROXYREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.serverless.mdbproxy.v1.proxy_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.mdbproxy.v1.CreateProxyRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEPROXYREQUEST,
  '__module__' : 'yandex.cloud.serverless.mdbproxy.v1.proxy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.mdbproxy.v1.CreateProxyRequest)
  })
_sym_db.RegisterMessage(CreateProxyRequest)
_sym_db.RegisterMessage(CreateProxyRequest.LabelsEntry)

CreateProxyMetadata = _reflection.GeneratedProtocolMessageType('CreateProxyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROXYMETADATA,
  '__module__' : 'yandex.cloud.serverless.mdbproxy.v1.proxy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.mdbproxy.v1.CreateProxyMetadata)
  })
_sym_db.RegisterMessage(CreateProxyMetadata)

UpdateProxyRequest = _reflection.GeneratedProtocolMessageType('UpdateProxyRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEPROXYREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.serverless.mdbproxy.v1.proxy_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.mdbproxy.v1.UpdateProxyRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEPROXYREQUEST,
  '__module__' : 'yandex.cloud.serverless.mdbproxy.v1.proxy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.mdbproxy.v1.UpdateProxyRequest)
  })
_sym_db.RegisterMessage(UpdateProxyRequest)
_sym_db.RegisterMessage(UpdateProxyRequest.LabelsEntry)

UpdateProxyMetadata = _reflection.GeneratedProtocolMessageType('UpdateProxyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROXYMETADATA,
  '__module__' : 'yandex.cloud.serverless.mdbproxy.v1.proxy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.mdbproxy.v1.UpdateProxyMetadata)
  })
_sym_db.RegisterMessage(UpdateProxyMetadata)

DeleteProxyRequest = _reflection.GeneratedProtocolMessageType('DeleteProxyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPROXYREQUEST,
  '__module__' : 'yandex.cloud.serverless.mdbproxy.v1.proxy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.mdbproxy.v1.DeleteProxyRequest)
  })
_sym_db.RegisterMessage(DeleteProxyRequest)

DeleteProxyMetadata = _reflection.GeneratedProtocolMessageType('DeleteProxyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPROXYMETADATA,
  '__module__' : 'yandex.cloud.serverless.mdbproxy.v1.proxy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.mdbproxy.v1.DeleteProxyMetadata)
  })
_sym_db.RegisterMessage(DeleteProxyMetadata)

ListProxyOperationsRequest = _reflection.GeneratedProtocolMessageType('ListProxyOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROXYOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.serverless.mdbproxy.v1.proxy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.mdbproxy.v1.ListProxyOperationsRequest)
  })
_sym_db.RegisterMessage(ListProxyOperationsRequest)

ListProxyOperationsResponse = _reflection.GeneratedProtocolMessageType('ListProxyOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROXYOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.serverless.mdbproxy.v1.proxy_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.mdbproxy.v1.ListProxyOperationsResponse)
  })
_sym_db.RegisterMessage(ListProxyOperationsResponse)


DESCRIPTOR._options = None
_GETPROXYREQUEST.fields_by_name['proxy_id']._options = None
_LISTPROXYREQUEST.fields_by_name['folder_id']._options = None
_LISTPROXYREQUEST.fields_by_name['page_size']._options = None
_LISTPROXYREQUEST.fields_by_name['page_token']._options = None
_LISTPROXYREQUEST.fields_by_name['filter']._options = None
_LISTPROXYRESPONSE.fields_by_name['next_page_token']._options = None
_CREATEPROXYREQUEST_LABELSENTRY._options = None
_CREATEPROXYREQUEST.fields_by_name['folder_id']._options = None
_CREATEPROXYREQUEST.fields_by_name['name']._options = None
_CREATEPROXYREQUEST.fields_by_name['description']._options = None
_CREATEPROXYREQUEST.fields_by_name['labels']._options = None
_CREATEPROXYREQUEST.fields_by_name['target']._options = None
_CREATEPROXYMETADATA.fields_by_name['proxy_id']._options = None
_UPDATEPROXYREQUEST_LABELSENTRY._options = None
_UPDATEPROXYREQUEST.fields_by_name['proxy_id']._options = None
_UPDATEPROXYREQUEST.fields_by_name['name']._options = None
_UPDATEPROXYREQUEST.fields_by_name['description']._options = None
_UPDATEPROXYREQUEST.fields_by_name['labels']._options = None
_UPDATEPROXYMETADATA.fields_by_name['proxy_id']._options = None
_DELETEPROXYREQUEST.fields_by_name['proxy_id']._options = None
_DELETEPROXYMETADATA.fields_by_name['proxy_id']._options = None
_LISTPROXYOPERATIONSREQUEST.fields_by_name['proxy_id']._options = None
_LISTPROXYOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTPROXYOPERATIONSREQUEST.fields_by_name['page_token']._options = None
_LISTPROXYOPERATIONSREQUEST.fields_by_name['filter']._options = None

_PROXYSERVICE = _descriptor.ServiceDescriptor(
  name='ProxyService',
  full_name='yandex.cloud.serverless.mdbproxy.v1.ProxyService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1979,
  serialized_end=3687,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.serverless.mdbproxy.v1.ProxyService.Get',
    index=0,
    containing_service=None,
    input_type=_GETPROXYREQUEST,
    output_type=yandex_dot_cloud_dot_serverless_dot_mdbproxy_dot_v1_dot_proxy__pb2._PROXY,
    serialized_options=b'\202\323\344\223\002!\022\037/mdbproxy/v1/proxies/{proxy_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.serverless.mdbproxy.v1.ProxyService.List',
    index=1,
    containing_service=None,
    input_type=_LISTPROXYREQUEST,
    output_type=_LISTPROXYRESPONSE,
    serialized_options=b'\202\323\344\223\002\026\022\024/mdbproxy/v1/proxies',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.serverless.mdbproxy.v1.ProxyService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEPROXYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\031\"\024/mdbproxy/v1/proxies:\001*\262\322*\034\n\023CreateProxyMetadata\022\005Proxy',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.serverless.mdbproxy.v1.ProxyService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEPROXYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002$2\037/mdbproxy/v1/proxies/{proxy_id}:\001*\262\322*\034\n\023UpdateProxyMetadata\022\005Proxy',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.serverless.mdbproxy.v1.ProxyService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEPROXYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002!*\037/mdbproxy/v1/proxies/{proxy_id}\262\322*,\n\023DeleteProxyMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.serverless.mdbproxy.v1.ProxyService.ListOperations',
    index=5,
    containing_service=None,
    input_type=_LISTPROXYOPERATIONSREQUEST,
    output_type=_LISTPROXYOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002,\022*/mdbproxy/v1/proxies/{proxy_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAccessBindings',
    full_name='yandex.cloud.serverless.mdbproxy.v1.ProxyService.ListAccessBindings',
    index=6,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_access_dot_access__pb2._LISTACCESSBINDINGSRESPONSE,
    serialized_options=b'\202\323\344\223\0027\0225/mdbproxy/v1/proxies/{resource_id}:listAccessBindings',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetAccessBindings',
    full_name='yandex.cloud.serverless.mdbproxy.v1.ProxyService.SetAccessBindings',
    index=7,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._SETACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0029\"4/mdbproxy/v1/proxies/{resource_id}:setAccessBindings:\001*\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccessBindings',
    full_name='yandex.cloud.serverless.mdbproxy.v1.ProxyService.UpdateAccessBindings',
    index=8,
    containing_service=None,
    input_type=yandex_dot_cloud_dot_access_dot_access__pb2._UPDATEACCESSBINDINGSREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002<27/mdbproxy/v1/proxies/{resource_id}:updateAccessBindings:\001*\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PROXYSERVICE)

DESCRIPTOR.services_by_name['ProxyService'] = _PROXYSERVICE

# @@protoc_insertion_point(module_scope)
