# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/lockbox/v1/payload.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/lockbox/v1/payload.proto',
  package='yandex.cloud.lockbox.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.lockbox.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/lockbox/v1;lockbox',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%yandex/cloud/lockbox/v1/payload.proto\x12\x17yandex.cloud.lockbox.v1\"\xa3\x01\n\x07Payload\x12\x12\n\nversion_id\x18\x01 \x01(\t\x12\x37\n\x07\x65ntries\x18\x02 \x03(\x0b\x32&.yandex.cloud.lockbox.v1.Payload.Entry\x1aK\n\x05\x45ntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x14\n\ntext_value\x18\x02 \x01(\tH\x00\x12\x16\n\x0c\x62inary_value\x18\x03 \x01(\x0cH\x00\x42\x07\n\x05valueBb\n\x1byandex.cloud.api.lockbox.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/lockbox/v1;lockboxb\x06proto3'
)




_PAYLOAD_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='yandex.cloud.lockbox.v1.Payload.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.lockbox.v1.Payload.Entry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_value', full_name='yandex.cloud.lockbox.v1.Payload.Entry.text_value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binary_value', full_name='yandex.cloud.lockbox.v1.Payload.Entry.binary_value', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='yandex.cloud.lockbox.v1.Payload.Entry.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=155,
  serialized_end=230,
)

_PAYLOAD = _descriptor.Descriptor(
  name='Payload',
  full_name='yandex.cloud.lockbox.v1.Payload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version_id', full_name='yandex.cloud.lockbox.v1.Payload.version_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entries', full_name='yandex.cloud.lockbox.v1.Payload.entries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PAYLOAD_ENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=230,
)

_PAYLOAD_ENTRY.containing_type = _PAYLOAD
_PAYLOAD_ENTRY.oneofs_by_name['value'].fields.append(
  _PAYLOAD_ENTRY.fields_by_name['text_value'])
_PAYLOAD_ENTRY.fields_by_name['text_value'].containing_oneof = _PAYLOAD_ENTRY.oneofs_by_name['value']
_PAYLOAD_ENTRY.oneofs_by_name['value'].fields.append(
  _PAYLOAD_ENTRY.fields_by_name['binary_value'])
_PAYLOAD_ENTRY.fields_by_name['binary_value'].containing_oneof = _PAYLOAD_ENTRY.oneofs_by_name['value']
_PAYLOAD.fields_by_name['entries'].message_type = _PAYLOAD_ENTRY
DESCRIPTOR.message_types_by_name['Payload'] = _PAYLOAD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Payload = _reflection.GeneratedProtocolMessageType('Payload', (_message.Message,), {

  'Entry' : _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), {
    'DESCRIPTOR' : _PAYLOAD_ENTRY,
    '__module__' : 'yandex.cloud.lockbox.v1.payload_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.lockbox.v1.Payload.Entry)
    })
  ,
  'DESCRIPTOR' : _PAYLOAD,
  '__module__' : 'yandex.cloud.lockbox.v1.payload_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.lockbox.v1.Payload)
  })
_sym_db.RegisterMessage(Payload)
_sym_db.RegisterMessage(Payload.Entry)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
